@@ -184,10 +184,10 @@ RECURSIVE FUNCTION zLOG_GAMMA(Z) RESULT(RES)
 !  USE HYP_2F1_MODULE
   IMPLICIT NONE
   INTEGER, PARAMETER :: PR=KIND(1.0D0),IPR=KIND(1)
-  REAL(PR)     :: ZERO=0.0D0,ONE=1.0D0,TWO=2.0D0,HALF=0.50D0
+  REAL(PR)     :: ZERO=0.0D0,ONE=1.0D0,HALF=0.50D0
   REAL(PR)     :: M_PI=3.14159265358979323846D0
   REAL(PR)     :: M_PI_2=1.57079632679489661923D0
-  REAL(PR)     :: M_1_PI=0.31830988618379067154D0 
+
 
   COMPLEX(PR),INTENT(IN) :: Z
   INTEGER(IPR) :: N,I
@@ -195,6 +195,7 @@ RECURSIVE FUNCTION zLOG_GAMMA(Z) RESULT(RES)
   COMPLEX(PR)  :: GAMMA_SUM,Z_M_0P5,Z_P_G_M0P5,ZM1
   COMPLEX(PR)  :: LOG_CONST,I_PI,EPS,LOG_SIN_PI_Z,RES
   !
+  RES = 0.0D0
   M_LN2=0.69314718055994530942D0; X=REAL(Z,PR); Y=AIMAG(Z)
   IF((Z.EQ.NINT(X)).AND.(X.LE.ZERO)) &
        return
@@ -262,9 +263,9 @@ RECURSIVE FUNCTION GAMMA_INV(Z) RESULT(RES)
 !  USE HYP_2F1_MODULE
   IMPLICIT NONE
   INTEGER, PARAMETER :: PR=KIND(1.0D0),IPR=KIND(1)
-  REAL(PR)     :: ZERO=0.0D0,ONE=1.0D0,TWO=2.0D0,HALF=0.50D0
+  REAL(PR)     :: ONE=1.0D0,HALF=0.50D0
   REAL(PR)     :: M_PI=3.14159265358979323846D0
-  REAL(PR)     :: M_PI_2=1.57079632679489661923D0
+
   REAL(PR)     :: M_1_PI=0.31830988618379067154D0 
 
   COMPLEX(PR),INTENT(IN) :: Z
@@ -390,7 +391,7 @@ RECURSIVE FUNCTION GAMMA_RATIO_DIFF_SMALL_EPS(Z,EPS) RESULT(RES)
   REAL(PR)     :: ZERO=0.0D0,ONE=1.0D0,TWO=2.0D0,HALF=0.50D0
   REAL(PR)     :: M_PI=3.14159265358979323846D0
   REAL(PR)     :: M_PI_2=1.57079632679489661923D0
-  REAL(PR)     :: M_1_PI=0.31830988618379067154D0 
+
 
   COMPLEX(PR),INTENT(IN) :: Z,EPS
   INTEGER(IPR)           :: N,M,I
@@ -402,6 +403,7 @@ RECURSIVE FUNCTION GAMMA_RATIO_DIFF_SMALL_EPS(Z,EPS) RESULT(RES)
   REAL(PR), EXTERNAL     :: INF_NORM
   COMPLEX(PR), EXTERNAL  :: LOG1P, TANZ, EXPM1
   !
+  RES = 0.0D0
   G=4.74218750D0
   IF(INF_NORM(EPS).GT.0.1D0) &
         return
@@ -527,7 +529,7 @@ FUNCTION GAMMA_INV_DIFF_EPS(Z,EPS)
 !  USE HYP_2F1_MODULE
   IMPLICIT NONE
   INTEGER, PARAMETER :: PR=KIND(1.0D0),IPR=KIND(1)
-  REAL(PR)           :: ZERO=0.0D0,ONE=1.0D0,TWO=2.0D0,HALF=0.50D0
+  REAL(PR)           :: ONE=1.0D0
   COMPLEX(PR),INTENT(IN) :: Z,EPS
   INTEGER(IPR)       :: M,N,K
   REAL(PR)           :: X,EPS_PX,FACT
@@ -625,7 +627,7 @@ FUNCTION A_SUM_INIT(M,EPS,GAMMA_INV_ONE_MEPS)
 !  USE HYP_2F1_MODULE
   IMPLICIT NONE
   INTEGER, PARAMETER :: PR=KIND(1.0D0),IPR=KIND(1)
-  REAL(PR)     :: ZERO=0.0D0,ONE=1.0D0,TWO=2.0D0,HALF=0.50D0
+  REAL(PR)     :: ONE=1.0D0
   INTEGER(IPR),INTENT(IN) :: M
   COMPLEX(PR),INTENT(IN) :: EPS,GAMMA_INV_ONE_MEPS
   INTEGER(IPR) :: N,I
@@ -675,10 +677,10 @@ FUNCTION LOG_A_SUM_INIT(M,EPS)
 !  USE HYP_2F1_MODULE
   IMPLICIT NONE
   INTEGER, PARAMETER :: PR=KIND(1.0D0),IPR=KIND(1)
-  REAL(PR)     :: ZERO=0.0D0,ONE=1.0D0,TWO=2.0D0,HALF=0.50D0
+  REAL(PR)     :: ZERO=0.0D0,ONE=1.0D0
   REAL(PR)     :: M_PI=3.14159265358979323846D0
-  REAL(PR)     :: M_PI_2=1.57079632679489661923D0
-  REAL(PR)     :: M_1_PI=0.31830988618379067154D0 
+
+
 
   INTEGER(IPR),INTENT(IN) :: M
   COMPLEX(PR),INTENT(IN) :: EPS
@@ -799,10 +801,10 @@ FUNCTION B_SUM_INIT_PS_ONE(A,B,GAMMA_C,GAMMA_INV_ONE_MEPS, &
 !  USE HYP_2F1_MODULE
   IMPLICIT NONE
   INTEGER, PARAMETER :: PR=KIND(1.0D0),IPR=KIND(1)
-  REAL(PR)     :: ZERO=0.0D0,ONE=1.0D0,TWO=2.0D0,HALF=0.50D0
+  REAL(PR)     :: ONE=1.0D0
   REAL(PR)     :: M_PI=3.14159265358979323846D0
-  REAL(PR)     :: M_PI_2=1.57079632679489661923D0
-  REAL(PR)     :: M_1_PI=0.31830988618379067154D0 
+
+
 
   INTEGER(IPR),INTENT(IN) :: M
   COMPLEX(PR),INTENT(IN) :: A,B,GAMMA_C,GAMMA_INV_ONE_MEPS, &
@@ -979,10 +981,10 @@ FUNCTION B_SUM_INIT_PS_INFINITY(A,C,GAMMA_C,GAMMA_INV_CMA, &
 !  USE HYP_2F1_MODULE
   IMPLICIT NONE
   INTEGER, PARAMETER :: PR=KIND(1.0D0),IPR=KIND(1)
-  REAL(PR)     :: ZERO=0.0D0,ONE=1.0D0,TWO=2.0D0,HALF=0.50D0
+  REAL(PR)     :: ZERO=0.0D0,ONE=1.0D0
   REAL(PR)     :: M_PI=3.14159265358979323846D0
-  REAL(PR)     :: M_PI_2=1.57079632679489661923D0
-  REAL(PR)     :: M_1_PI=0.31830988618379067154D0 
+
+
 
   INTEGER(IPR),INTENT(IN) :: M
   COMPLEX(PR),INTENT(IN) :: A,C,GAMMA_C,GAMMA_INV_CMA,Z,EPS
@@ -1117,7 +1119,7 @@ SUBROUTINE CV_POLY_DER_TAB_CALC(A,B,C,Z,CV_POLY_DER_TAB)
 !  USE HYP_2F1_MODULE
   IMPLICIT NONE
   INTEGER, PARAMETER :: PR=KIND(1.0D0),IPR=KIND(1)
-  REAL(PR)     :: ZERO=0.0D0,ONE=1.0D0,TWO=2.0D0,HALF=0.50D0
+  REAL(PR)     :: ONE=1.0D0,TWO=2.0D0
   COMPLEX(PR),INTENT(IN) :: A,B,C,Z
   REAL(PR),INTENT(OUT) :: CV_POLY_DER_TAB(0:3)
   REAL(PR)     :: MOD_A2,MOD_B2,MOD_C2,MOD_Z2
@@ -1195,7 +1197,7 @@ FUNCTION MIN_N_CALC(CV_POLY_DER_TAB)
 !  USE HYP_2F1_MODULE
   IMPLICIT NONE
   INTEGER, PARAMETER :: PR=KIND(1.0D0),IPR=KIND(1)
-  REAL(PR)     :: ZERO=0.0D0,ONE=1.0D0,TWO=2.0D0,HALF=0.50D0
+  REAL(PR)     :: ZERO=0.0D0
 
   REAL(PR),INTENT(IN) :: CV_POLY_DER_TAB(0:3)
   INTEGER(IPR) :: MIN_N_CALC
@@ -1249,7 +1251,7 @@ FUNCTION HYP_PS_ZERO(A,B,C,Z)
   IMPLICIT NONE
   INTEGER, PARAMETER :: PR=KIND(1.0D0),IPR=KIND(1)
   REAL(PR)     :: EPS15=1.0D-15
-  REAL(PR)     :: ZERO=0.0D0,ONE=1.0D0,TWO=2.0D0,HALF=0.50D0
+  REAL(PR)     :: ZERO=0.0D0,ONE=1.0D0
 
   COMPLEX(PR),INTENT(IN) :: A,B,C,Z
   INTEGER(IPR) :: N,NA,NB,MIN_N,MIN_N_CALC
@@ -1369,10 +1371,10 @@ FUNCTION HYP_PS_ONE(A,B,C,MZP1)
   IMPLICIT NONE
   INTEGER, PARAMETER :: PR=KIND(1.0D0),IPR=KIND(1)
   REAL(PR)     :: EPS15=1.0D-15
-  REAL(PR)     :: ZERO=0.0D0,ONE=1.0D0,TWO=2.0D0,HALF=0.50D0
+  REAL(PR)     :: ZERO=0.0D0,ONE=1.0D0
   REAL(PR)     :: M_PI=3.14159265358979323846D0
-  REAL(PR)     :: M_PI_2=1.57079632679489661923D0
-  REAL(PR)     :: M_1_PI=0.31830988618379067154D0 
+
+
 
   COMPLEX(PR),INTENT(IN) :: A,B,C,MZP1
   INTEGER(IPR) :: N,M,PHASE,M_M2,MIN_N,MIN_N_CALC,M_P1
@@ -1546,10 +1548,10 @@ FUNCTION HYP_PS_INFINITY(A,B,C,Z)
   IMPLICIT NONE
   INTEGER, PARAMETER :: PR=KIND(1.0D0),IPR=KIND(1)
   REAL(PR)     :: EPS15=1.0D-15
-  REAL(PR)     :: ZERO=0.0D0,ONE=1.0D0,TWO=2.0D0,HALF=0.50D0
+  REAL(PR)     :: ZERO=0.0D0,ONE=1.0D0
   REAL(PR)     :: M_PI=3.14159265358979323846D0
-  REAL(PR)     :: M_PI_2=1.57079632679489661923D0
-  REAL(PR)     :: M_1_PI=0.31830988618379067154D0 
+
+
 
   COMPLEX(PR),INTENT(IN) :: A,B,C,Z
   INTEGER(IPR) :: N,M,PHASE,M_M2,MIN_N,MIN_N_CALC,M_P1
@@ -1699,7 +1701,7 @@ FUNCTION HYP_PS_COMPLEX_PLANE_REST(A,B,C,Z)
 !  USE HYP_2F1_MODULE
   IMPLICIT NONE
   INTEGER, PARAMETER :: PR=KIND(1.0D0),IPR=KIND(1)
-  REAL(PR)     :: ZERO=0.0D0,ONE=1.0D0,TWO=2.0D0,HALF=0.50D0
+  REAL(PR)     :: ONE=1.0D0,TWO=2.0D0
   REAL(PR)     :: EPS15=1.0D-15
 
   COMPLEX(PR),INTENT(IN) :: A,B,C,Z
@@ -1813,7 +1815,7 @@ RECURSIVE FUNCTION HYP_2F1(A,B,C,Z) RESULT(RES)
 !  USE HYP_2F1_MODULE
   IMPLICIT NONE
   INTEGER, PARAMETER :: PR=KIND(1.0D0),IPR=KIND(1)
-  REAL(PR)     :: ZERO=0.0D0,ONE=1.0D0,TWO=2.0D0,HALF=0.50D0
+  REAL(PR)     :: ZERO=0.0D0,ONE=1.0D0
 
   COMPLEX(PR),INTENT(IN) :: A,B,C,Z
   INTEGER(IPR) :: NA,NB,NC,I
@@ -1826,6 +1828,7 @@ RECURSIVE FUNCTION HYP_2F1(A,B,C,Z) RESULT(RES)
   LOGICAL      :: IS_CMB_SMALL,ARE_AC_SMALL,ARE_ABC_SMALL
   REAL(PR), EXTERNAL     :: INF_NORM
   !
+  RES = 0.0D0
   RE_A=REAL(A,PR); RE_B=REAL(B,PR); RE_C=REAL(C,PR);
   NA=NINT(RE_A); NB=NINT(RE_B); NC=NINT(RE_C);
   IS_A_NEG_INT=A.EQ.NA.AND.NA.LE.0
